<?php

namespace EventPortal\Tests\Feature\Admin\Delegate;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class CreateDelegateFromExistingUserTest extends TestCase
{
    use DatabaseMigrations;

    /** @test */
    public function can_create_a_delegate_from_an_existing_user(): void
    {
        $permission = factory(Permission::class)->create([
            'name' => 'delegate.store',
        ]);
        $admin = factory(Admin::class)->create();
        $admin->givePermissionTo($permission);
        $this->assertCount(0, Delegate::all());

        $this->actingAs($admin->user)->post(route('admin.delegate.store', [
            'email' => $admin->user->email,
            'first_name' => 'A first name',
            'last_name' => 'A last name',
        ]));

        $this->assertCount(1, User::all());
        $this->assertCount(1, Delegate::all());
        $delegate = Delegate::first();

        $this->assertEquals($admin->user->id, $delegate->user_id);
        $this->assertEquals('A first name', $delegate->user->first_name);
        $this->assertEquals('A last name', $delegate->user->last_name);
    }
}
